pub enum InfoId<'a> {
Show 16 variants
Away,
Channel,
Charset,
Configdir,
EventText(&'a str),
Host,
Inputbox,
Libdirfs,
Modes,
Network,
Nick,
Nickserv,
Server,
Topic,
Version,
WinStatus,
}Expand description
A hexchat_get_info key.
Variants
Away
Returns the away message, or None if the user is not away.
Channel
Returns the current channel name.
Charset
Returns the current charset.
Configdir
Returns the hexchat configuration directory, e.g. /home/user/.config/hexchat.
EventText(&'a str)
Returns the text event format string for the given text event name.
Host
Returns the (real) hostname of the current server.
Inputbox
Returns the contents of the input box.
Libdirfs
Returns the library directory, e.g. /usr/lib/hexchat.
May not always work, as this string isn’t necessarily UTF-8, but local file system encoding.
Modes
Returns the channel modes, if known, or None.
Network
Returns the current network name, or None.
Nick
Returns the user’s current nick.
Nickserv
Returns the user’s nickserv password, if any, or None
Server
Returns the current server name, or None if you are not connected.
Topic
Returns the current channel topic.
Version
Returns the HexChat version string.
WinStatus
Returns the window status: “active”, “hidden” or “normal”.