[−][src]Enum hexchat_plugin::InfoId
A hexchat_get_info key.
Variants
AwayReturns the away message, or None if the user is not away.
ChannelReturns the current channel name.
CharsetReturns the current charset.
ConfigdirReturns the hexchat configuration directory, e.g. /home/user/.config/hexchat.
EventText(&'a str)Returns the text event format string for the given text event name.
HostReturns the (real) hostname of the current server.
InputboxReturns the contents of the input box.
LibdirfsReturns the library directory, e.g. /usr/lib/hexchat.
May not always work, as this string isn't necessarily UTF-8, but local file system encoding.
ModesReturns the channel modes, if known, or None.
NetworkReturns the current network name, or None.
NickReturns the user's current nick.
NickservReturns the user's nickserv password, if any, or None
ServerReturns the current server name, or None if you are not connected.
TopicReturns the current channel topic.
VersionReturns the HexChat version string.
WinStatusReturns the window status: "active", "hidden" or "normal".
Methods
impl<'a> InfoId<'a>[src]